You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2007/04/15 21:08:15 UTC

svn commit: r529046 [2/5] - in /directory/apacheds/trunk/core/src: main/java/org/apache/directory/server/core/ main/java/org/apache/directory/server/core/authn/ main/java/org/apache/directory/server/core/authz/ main/java/org/apache/directory/server/cor...

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/exception/ExceptionService.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/exception/ExceptionService.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/exception/ExceptionService.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/exception/ExceptionService.java Sun Apr 15 12:08:12 2007
@@ -33,14 +33,15 @@
 import org.apache.directory.server.core.configuration.InterceptorConfiguration;
 import org.apache.directory.server.core.interceptor.BaseInterceptor;
 import org.apache.directory.server.core.interceptor.NextInterceptor;
-import org.apache.directory.server.core.interceptor.context.EntryServiceContext;
-import org.apache.directory.server.core.interceptor.context.GetMatchedNameServiceContext;
-import org.apache.directory.server.core.interceptor.context.LookupServiceContext;
-import org.apache.directory.server.core.interceptor.context.RenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.ModifyServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveAndRenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveServiceContext;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.EntryOperationContext;
+import org.apache.directory.server.core.interceptor.context.GetMatchedNameOperationContext;
+import org.apache.directory.server.core.interceptor.context.ListOperationContext;
+import org.apache.directory.server.core.interceptor.context.LookupOperationContext;
+import org.apache.directory.server.core.interceptor.context.RenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.ModifyOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveAndRenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveOperationContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.invocation.Invocation;
 import org.apache.directory.server.core.invocation.InvocationStack;
 import org.apache.directory.server.core.partition.Partition;
@@ -107,10 +108,10 @@
      * In the pre-invocation state this interceptor method checks to see if the entry to be added already exists.  If it
      * does an exception is raised.
      */
-    public void add( NextInterceptor nextInterceptor, ServiceContext addContext )
+    public void add( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-    	LdapDN name = addContext.getDn();
+    	LdapDN name = opContext.getDn();
     	
         if ( subschemSubentryDn.getNormName().equals( name.getNormName() ) )
         {
@@ -119,7 +120,7 @@
         }
         
         // check if the entry already exists
-        if ( nextInterceptor.hasEntry( new EntryServiceContext( name ) ) )
+        if ( nextInterceptor.hasEntry( new EntryOperationContext( name ) ) )
         {
             NamingException ne = new LdapNameAlreadyBoundException( name.getUpName() + " already exists!" );
             ne.setResolvedName( new LdapDN( name.getUpName() ) );
@@ -134,13 +135,13 @@
         
         try
         {
-            attrs = nextInterceptor.lookup( new LookupServiceContext( parentDn ) );
+            attrs = nextInterceptor.lookup( new LookupOperationContext( parentDn ) );
         }
         catch ( Exception e )
         {
             LdapNameNotFoundException e2 = new LdapNameNotFoundException( "Parent " + parentDn.getUpName() 
                 + " not found" );
-            e2.setResolvedName( new LdapDN( nexus.getMatchedName( new GetMatchedNameServiceContext( parentDn ) ).getUpName() ) );
+            e2.setResolvedName( new LdapDN( nexus.getMatchedName( new GetMatchedNameOperationContext( parentDn ) ).getUpName() ) );
             throw e2;
         }
         
@@ -155,7 +156,7 @@
             throw e;
         }
 
-        nextInterceptor.add( addContext );
+        nextInterceptor.add( opContext );
     }
 
 
@@ -163,9 +164,9 @@
      * Checks to make sure the entry being deleted exists, and has no children, otherwise throws the appropriate
      * LdapException.
      */
-    public void delete( NextInterceptor nextInterceptor, ServiceContext deleteContext ) throws NamingException
+    public void delete( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-    	LdapDN name = deleteContext.getDn();
+    	LdapDN name = opContext.getDn();
     	
         if ( name.getNormName().equalsIgnoreCase( subschemSubentryDn.getNormName() ) )
         {
@@ -181,7 +182,7 @@
 
         // check if entry to delete has children (only leaves can be deleted)
         boolean hasChildren = false;
-        NamingEnumeration list = nextInterceptor.list( name );
+        NamingEnumeration list = nextInterceptor.list( new ListOperationContext( name ) );
         
         if ( list.hasMore() )
         {
@@ -197,16 +198,16 @@
             throw e;
         }
 
-        nextInterceptor.delete( deleteContext );
+        nextInterceptor.delete( opContext );
     }
 
 
     /**
      * Checks to see the base being searched exists, otherwise throws the appropriate LdapException.
      */
-    public NamingEnumeration list( NextInterceptor nextInterceptor, LdapDN baseName ) throws NamingException
+    public NamingEnumeration list( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        if ( baseName.getNormName().equals( subschemSubentryDn.getNormName() ) )
+        if ( opContext.getDn().getNormName().equals( subschemSubentryDn.getNormName() ) )
         {
             // there is nothing under the schema subentry
             return new EmptyEnumeration();
@@ -214,18 +215,18 @@
         
         // check if entry to search exists
         String msg = "Attempt to search under non-existant entry: ";
-        assertHasEntry( nextInterceptor, msg, baseName );
+        assertHasEntry( nextInterceptor, msg, opContext.getDn() );
 
-        return nextInterceptor.list( baseName );
+        return nextInterceptor.list( opContext );
     }
 
 
     /**
      * Checks to see the base being searched exists, otherwise throws the appropriate LdapException.
      */
-    public Attributes lookup( NextInterceptor nextInterceptor, ServiceContext lookupContext ) throws NamingException
+    public Attributes lookup( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LookupServiceContext ctx = (LookupServiceContext)lookupContext;
+        LookupOperationContext ctx = (LookupOperationContext)opContext;
         
         if ( ctx.getDn().getNormName().equals( subschemSubentryDn.getNormName() ) )
         {
@@ -236,17 +237,17 @@
         String msg = "Attempt to lookup non-existant entry: ";
         assertHasEntry( nextInterceptor, msg, ctx.getDn() );
 
-        return nextInterceptor.lookup( lookupContext );
+        return nextInterceptor.lookup( opContext );
     }
 
 
     /**
      * Checks to see the entry being modified exists, otherwise throws the appropriate LdapException.
      */
-    public void modify( NextInterceptor nextInterceptor, ServiceContext modifyContext )
+    public void modify( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-    	ModifyServiceContext ctx = (ModifyServiceContext)modifyContext;
+    	ModifyOperationContext ctx = (ModifyOperationContext)opContext;
 
         // check if entry to modify exists
         String msg = "Attempt to modify non-existant entry: ";
@@ -255,13 +256,13 @@
         // and never try to look it up in the nexus below
         if ( ctx.getDn().getNormName().equalsIgnoreCase( subschemSubentryDn.getNormName() ) )
         {
-            nextInterceptor.modify( modifyContext );
+            nextInterceptor.modify( opContext );
             return;
         }
         
         assertHasEntry( nextInterceptor, msg, ctx.getDn() );
 
-        Attributes entry = nexus.lookup( new LookupServiceContext( ctx.getDn() ) );
+        Attributes entry = nexus.lookup( new LookupOperationContext( ctx.getDn() ) );
         NamingEnumeration attrIds = ctx.getMods().getIDs();
         
         while ( attrIds.hasMore() )
@@ -286,7 +287,7 @@
             }
         }
         
-        nextInterceptor.modify( modifyContext );
+        nextInterceptor.modify( opContext );
     }
 
 
@@ -308,7 +309,7 @@
         
         assertHasEntry( nextInterceptor, msg, name );
 
-        Attributes entry = nexus.lookup( new LookupServiceContext( name ) );
+        Attributes entry = nexus.lookup( new LookupOperationContext( name ) );
         for ( int ii = 0; ii < items.length; ii++ )
         {
             if ( items[ii].getModificationOp() == DirContext.ADD_ATTRIBUTE )
@@ -336,10 +337,10 @@
     /**
      * Checks to see the entry being renamed exists, otherwise throws the appropriate LdapException.
      */
-    public void rename( NextInterceptor nextInterceptor, ServiceContext renameContext )
+    public void rename( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-        LdapDN dn = renameContext.getDn();
+        LdapDN dn = opContext.getDn();
         
         if ( dn.getNormName().equalsIgnoreCase( subschemSubentryDn.getNormName() ) )
         {
@@ -356,10 +357,10 @@
         // check to see if target entry exists
         LdapDN newDn = ( LdapDN ) dn.clone();
         newDn.remove( dn.size() - 1 );
-        newDn.add( ((RenameServiceContext)renameContext).getNewRdn() );
+        newDn.add( ((RenameOperationContext)opContext).getNewRdn() );
         newDn.normalize( normalizerMap );
         
-        if ( nextInterceptor.hasEntry( new EntryServiceContext( newDn ) ) )
+        if ( nextInterceptor.hasEntry( new EntryOperationContext( newDn ) ) )
         {
             LdapNameAlreadyBoundException e;
             e = new LdapNameAlreadyBoundException( "target entry " + newDn.getUpName() + " already exists!" );
@@ -367,7 +368,7 @@
             throw e;
         }
 
-        nextInterceptor.rename( renameContext );
+        nextInterceptor.rename( opContext );
     }
 
 
@@ -375,10 +376,10 @@
      * Checks to see the entry being moved exists, and so does its parent, otherwise throws the appropriate
      * LdapException.
      */
-    public void move( NextInterceptor nextInterceptor, ServiceContext moveContext ) throws NamingException
+    public void move( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN oriChildName = moveContext.getDn();
-        LdapDN newParentName = ((MoveServiceContext)moveContext).getParent();
+        LdapDN oriChildName = opContext.getDn();
+        LdapDN newParentName = ((MoveOperationContext)opContext).getParent();
         
         if ( oriChildName.getNormName().equalsIgnoreCase( subschemSubentryDn.getNormName() ) )
         {
@@ -401,7 +402,7 @@
         LdapDN target = ( LdapDN ) newParentName.clone();
         target.add( rdn );
         
-        if ( nextInterceptor.hasEntry( new EntryServiceContext( target ) ) )
+        if ( nextInterceptor.hasEntry( new EntryOperationContext( target ) ) )
         {
             // we must calculate the resolved name using the user provided Rdn value
             String upRdn = new LdapDN( oriChildName.getUpName() ).get( oriChildName.size() - 1 );
@@ -414,7 +415,7 @@
             throw e;
         }
 
-        nextInterceptor.move( moveContext );
+        nextInterceptor.move( opContext );
     }
 
 
@@ -422,11 +423,11 @@
      * Checks to see the entry being moved exists, and so does its parent, otherwise throws the appropriate
      * LdapException.
      */
-    public void moveAndRename( NextInterceptor nextInterceptor, ServiceContext moveAndRenameContext ) throws NamingException
+    public void moveAndRename( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN oriChildName = moveAndRenameContext.getDn();
-        LdapDN parent = ((MoveAndRenameServiceContext)moveAndRenameContext).getParent();
-        String newRn = ((MoveAndRenameServiceContext)moveAndRenameContext).getNewRdn();
+        LdapDN oriChildName = opContext.getDn();
+        LdapDN parent = ((MoveAndRenameOperationContext)opContext).getParent();
+        String newRn = ((MoveAndRenameOperationContext)opContext).getNewRdn();
         
         if ( oriChildName.getNormName().equalsIgnoreCase( subschemSubentryDn.getNormName() ) )
         {
@@ -449,7 +450,7 @@
         target.add( newRn );
         target.normalize( normalizerMap );
         
-        if ( nextInterceptor.hasEntry( new EntryServiceContext( target ) ) )
+        if ( nextInterceptor.hasEntry( new EntryOperationContext( target ) ) )
         {
             // we must calculate the resolved name using the user provided Rdn value
             LdapDN upTarget = ( LdapDN ) parent.clone();
@@ -461,7 +462,7 @@
             throw e;
         }
 
-        nextInterceptor.moveAndRename( moveAndRenameContext );
+        nextInterceptor.moveAndRename( opContext );
     }
 
 
@@ -507,7 +508,7 @@
         Invocation invocation = InvocationStack.getInstance().peek();
         PartitionNexusProxy proxy = invocation.getProxy();
         
-        if ( !nextInterceptor.hasEntry( new EntryServiceContext( dn ) ) )
+        if ( !nextInterceptor.hasEntry( new EntryOperationContext( dn ) ) )
         {
             LdapNameNotFoundException e;
 
@@ -523,7 +524,7 @@
             e.setResolvedName( 
                 new LdapDN( 
                     proxy.getMatchedName( 
-                        new GetMatchedNameServiceContext( dn ) ).getUpName() ) );
+                        new GetMatchedNameOperationContext( dn ) ).getUpName() ) );
             throw e;
         }
     }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java Sun Apr 15 12:08:12 2007
@@ -33,7 +33,7 @@
 import org.apache.directory.server.core.DirectoryServiceConfiguration;
 import org.apache.directory.server.core.authn.LdapPrincipal;
 import org.apache.directory.server.core.configuration.InterceptorConfiguration;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.invocation.InvocationStack;
 import org.apache.directory.server.core.jndi.ServerContext;
 import org.apache.directory.shared.ldap.filter.ExprNode;
@@ -98,63 +98,63 @@
     // Interceptor's Invoke Method
     // ------------------------------------------------------------------------
 
-    public void add(NextInterceptor next, ServiceContext addContext ) throws NamingException
+    public void add(NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.add( addContext );
+        next.add( opContext );
     }
 
 
-    public void delete( NextInterceptor next, ServiceContext deleteContext ) throws NamingException
+    public void delete( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.delete( deleteContext );
+        next.delete( opContext );
     }
 
 
-    public LdapDN getMatchedName ( NextInterceptor next, ServiceContext getMatchedNameContext ) throws NamingException
+    public LdapDN getMatchedName ( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.getMatchedName( getMatchedNameContext );
+        return next.getMatchedName( opContext );
     }
 
 
-    public Attributes getRootDSE( NextInterceptor next, ServiceContext getRootDSEContext ) throws NamingException
+    public Attributes getRootDSE( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.getRootDSE( getRootDSEContext );
+        return next.getRootDSE( opContext );
     }
 
 
-    public LdapDN getSuffix( NextInterceptor next, ServiceContext getSuffixContext ) throws NamingException
+    public LdapDN getSuffix( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.getSuffix( getSuffixContext );
+        return next.getSuffix( opContext );
     }
 
 
-    public boolean hasEntry( NextInterceptor next, ServiceContext entryContext ) throws NamingException
+    public boolean hasEntry( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.hasEntry( entryContext );
+        return next.hasEntry( opContext );
     }
 
 
-    public NamingEnumeration list( NextInterceptor next, LdapDN base ) throws NamingException
+    public NamingEnumeration list( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.list( base );
+        return next.list( opContext );
     }
 
 
-    public Iterator listSuffixes ( NextInterceptor next, ServiceContext emptyContext ) throws NamingException
+    public Iterator listSuffixes ( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.listSuffixes( emptyContext );
+        return next.listSuffixes( opContext );
     }
 
 
-    public Attributes lookup( NextInterceptor next, ServiceContext lookupContext ) throws NamingException
+    public Attributes lookup( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.lookup( lookupContext );
+        return next.lookup( opContext );
     }
 
     
-    public void modify( NextInterceptor next, ServiceContext modifyContext ) throws NamingException
+    public void modify( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.modify( modifyContext );
+        next.modify( opContext );
     }
 
 
@@ -164,22 +164,22 @@
     }
 
 
-    public void rename( NextInterceptor next, ServiceContext renameContext ) throws NamingException
+    public void rename( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.rename( renameContext );
+        next.rename( opContext );
     }
 
 
-    public void moveAndRename( NextInterceptor next, ServiceContext moveAndRenameContext )
+    public void moveAndRename( NextInterceptor next, OperationContext opContext )
         throws NamingException
     {
-        next.moveAndRename( moveAndRenameContext );
+        next.moveAndRename( opContext );
     }
 
 
-    public void move( NextInterceptor next, ServiceContext moveContext ) throws NamingException
+    public void move( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.move( moveContext );
+        next.move( opContext );
     }
 
 
@@ -190,33 +190,32 @@
     }
 
 
-    public void addContextPartition( NextInterceptor next, ServiceContext addContextPartitionContext ) throws NamingException
+    public void addContextPartition( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.addContextPartition( addContextPartitionContext );
+        next.addContextPartition( opContext );
     }
 
 
-    public void removeContextPartition( NextInterceptor next, ServiceContext removeContextPartition ) throws NamingException
+    public void removeContextPartition( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.removeContextPartition( removeContextPartition );
+        next.removeContextPartition( opContext );
     }
 
 
-    public boolean compare( NextInterceptor next, ServiceContext compareContext ) throws NamingException
+    public boolean compare( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        return next.compare( compareContext );
+        return next.compare( opContext );
     }
 
 
-    public void bind( NextInterceptor next, ServiceContext bindContext )
-    throws NamingException
+    public void bind( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.bind( bindContext );
+        next.bind( opContext );
     }
 
 
-    public void unbind( NextInterceptor next, ServiceContext unbindContext ) throws NamingException
+    public void unbind( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.unbind( unbindContext );
+        next.unbind( opContext );
     }
 }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java Sun Apr 15 12:08:12 2007
@@ -37,7 +37,7 @@
 import org.apache.directory.server.core.configuration.PartitionConfiguration;
 import org.apache.directory.server.core.configuration.InterceptorConfiguration;
 import org.apache.directory.server.core.configuration.MutableInterceptorConfiguration;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.invocation.Invocation;
 import org.apache.directory.server.core.invocation.InvocationStack;
 import org.apache.directory.server.core.partition.PartitionNexus;
@@ -79,51 +79,51 @@
         }
 
 
-        public boolean compare( NextInterceptor next, ServiceContext compareContext ) throws NamingException
+        public boolean compare( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return nexus.compare( compareContext );
+            return nexus.compare( opContext );
         }
 
 
-        public Attributes getRootDSE( NextInterceptor next, ServiceContext getRootDSEContext ) throws NamingException
+        public Attributes getRootDSE( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return nexus.getRootDSE( getRootDSEContext );
+            return nexus.getRootDSE( opContext );
         }
 
 
-        public LdapDN getMatchedName( NextInterceptor next, ServiceContext getMatchedNameContext ) throws NamingException
+        public LdapDN getMatchedName( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return ( LdapDN ) nexus.getMatchedName( getMatchedNameContext ).clone();
+            return ( LdapDN ) nexus.getMatchedName( opContext ).clone();
         }
 
 
-        public LdapDN getSuffix( NextInterceptor next, ServiceContext getSuffixContext ) throws NamingException
+        public LdapDN getSuffix( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return ( LdapDN ) nexus.getSuffix( getSuffixContext ).clone();
+            return ( LdapDN ) nexus.getSuffix( opContext ).clone();
         }
 
 
-        public Iterator listSuffixes( NextInterceptor next, ServiceContext emptyContext ) throws NamingException
+        public Iterator listSuffixes( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return nexus.listSuffixes( emptyContext );
+            return nexus.listSuffixes( opContext );
         }
 
 
-        public void delete( NextInterceptor next, ServiceContext deleteContext ) throws NamingException
+        public void delete( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            nexus.delete( deleteContext );
+            nexus.delete( opContext );
         }
 
 
-        public void add( NextInterceptor next, ServiceContext addContext ) throws NamingException
+        public void add( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            nexus.add( addContext );
+            nexus.add( opContext );
         }
 
 
-        public void modify( NextInterceptor next, ServiceContext modifyContext ) throws NamingException
+        public void modify( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            nexus.modify( modifyContext );
+            nexus.modify( opContext );
         }
 
 
@@ -133,9 +133,9 @@
         }
 
 
-        public NamingEnumeration list( NextInterceptor next, LdapDN base ) throws NamingException
+        public NamingEnumeration list( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return nexus.list( base );
+            return nexus.list( opContext );
         }
 
 
@@ -146,60 +146,60 @@
         }
 
 
-        public Attributes lookup( NextInterceptor next, ServiceContext lookupContext ) throws NamingException
+        public Attributes lookup( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return ( Attributes ) nexus.lookup( lookupContext ).clone();
+            return ( Attributes ) nexus.lookup( opContext ).clone();
         }
 
 
-        public boolean hasEntry( NextInterceptor next, ServiceContext entryContext ) throws NamingException
+        public boolean hasEntry( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            return nexus.hasEntry( entryContext );
+            return nexus.hasEntry( opContext );
         }
 
 
-        public void rename( NextInterceptor next, ServiceContext renameContext )
+        public void rename( NextInterceptor next, OperationContext opContext )
             throws NamingException
         {
-            nexus.rename( renameContext );
+            nexus.rename( opContext );
         }
 
 
-        public void move( NextInterceptor next, ServiceContext moveContext ) throws NamingException
+        public void move( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            nexus.move( moveContext );
+            nexus.move( opContext );
         }
 
 
-        public void moveAndRename( NextInterceptor next, ServiceContext moveAndRenameContext )
+        public void moveAndRename( NextInterceptor next, OperationContext opContext )
             throws NamingException
         {
-            nexus.moveAndRename( moveAndRenameContext );
+            nexus.moveAndRename( opContext );
         }
 
 
-        public void addContextPartition( NextInterceptor next, ServiceContext addContextPartitionContext )
+        public void addContextPartition( NextInterceptor next, OperationContext opContext )
             throws NamingException
         {
-            nexus.addContextPartition( addContextPartitionContext );
+            nexus.addContextPartition( opContext );
         }
 
 
-        public void removeContextPartition( NextInterceptor next, ServiceContext removeContextPartition ) throws NamingException
+        public void removeContextPartition( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            nexus.removeContextPartition( removeContextPartition );
+            nexus.removeContextPartition( opContext );
         }
 
 
-        public void bind( NextInterceptor next, ServiceContext bindContext )  throws NamingException
+        public void bind( NextInterceptor next, OperationContext opContext )  throws NamingException
         {
-            nexus.bind( bindContext );
+            nexus.bind( opContext );
         }
 
 
-        public void unbind( NextInterceptor next, ServiceContext unbindContext ) throws NamingException
+        public void unbind( NextInterceptor next, OperationContext opContext ) throws NamingException
         {
-            nexus.unbind( unbindContext );
+            nexus.unbind( opContext );
         }
     };
 
@@ -522,14 +522,15 @@
     }
 
 
-    public Attributes getRootDSE( ServiceContext getRootDSEContext ) throws NamingException
+    public Attributes getRootDSE( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            return head.getRootDSE( next, getRootDSEContext );
+            return head.getRootDSE( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -543,7 +544,7 @@
     }
 
 
-    public LdapDN getMatchedName( ServiceContext getMatchedNameContext ) throws NamingException
+    public LdapDN getMatchedName( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
@@ -551,7 +552,7 @@
 
         try
         {
-            return head.getMatchedName( next, getMatchedNameContext );
+            return head.getMatchedName( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -565,7 +566,7 @@
     }
 
 
-    public LdapDN getSuffix( ServiceContext getSuffixContext ) throws NamingException
+    public LdapDN getSuffix( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
@@ -573,7 +574,7 @@
         
         try
         {
-            return head.getSuffix( next, getSuffixContext );
+            return head.getSuffix( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -587,14 +588,15 @@
     }
 
 
-    public boolean compare( ServiceContext compareContext ) throws NamingException
+    public boolean compare( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            return head.compare( next, compareContext );
+            return head.compare( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -608,14 +610,15 @@
     }
 
 
-    public Iterator listSuffixes( ServiceContext emptyContext ) throws NamingException
+    public Iterator listSuffixes( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            return head.listSuffixes( next, emptyContext );
+            return head.listSuffixes( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -629,7 +632,7 @@
     }
 
 
-    public void addContextPartition( ServiceContext addContextPartitionContext ) throws NamingException
+    public void addContextPartition( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
@@ -637,7 +640,7 @@
         
         try
         {
-            head.addContextPartition( next, addContextPartitionContext );
+            head.addContextPartition( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -651,14 +654,15 @@
     }
 
 
-    public void removeContextPartition( ServiceContext removeContextPartition ) throws NamingException
+    public void removeContextPartition( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            head.removeContextPartition( next, removeContextPartition );
+            head.removeContextPartition( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -672,14 +676,15 @@
     }
 
 
-    public void delete( ServiceContext deleteContext ) throws NamingException
+    public void delete( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            head.delete( next, deleteContext );
+            head.delete( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -692,14 +697,15 @@
     }
 
 
-    public void add( ServiceContext addContext ) throws NamingException
+    public void add( OperationContext opContext ) throws NamingException
     {
         Entry node = getStartingEntry();
         Interceptor head = node.configuration.getInterceptor();
         NextInterceptor next = node.nextInterceptor;
+        
         try
         {
-            head.add( next, addContext );
+            head.add( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -712,14 +718,15 @@
     }
 
 
-    public void bind( ServiceContext bindContext ) throws NamingException
+    public void bind( OperationContext opContext ) throws NamingException
     {
         Entry node = getStartingEntry();
         Interceptor head = node.configuration.getInterceptor();
         NextInterceptor next = node.nextInterceptor;
+        
         try
         {
-            head.bind( next, bindContext );
+            head.bind( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -732,7 +739,7 @@
     }
 
 
-    public void unbind( ServiceContext unbindContext ) throws NamingException
+    public void unbind( OperationContext opContext ) throws NamingException
     {
         Entry node = getStartingEntry();
         Interceptor head = node.configuration.getInterceptor();
@@ -740,7 +747,7 @@
         
         try
         {
-            head.unbind( next, unbindContext );
+            head.unbind( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -753,14 +760,15 @@
     }
 
 
-    public void modify( ServiceContext modifyContext ) throws NamingException
+    public void modify( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            head.modify( next, modifyContext );
+            head.modify( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -778,6 +786,7 @@
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
             head.modify( next, name, mods );
@@ -793,14 +802,15 @@
     }
 
 
-    public NamingEnumeration list( LdapDN base ) throws NamingException
+    public NamingEnumeration list( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            return head.list( next, base );
+            return head.list( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -820,6 +830,7 @@
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
             return head.search( next, base, env, filter, searchCtls );
@@ -836,14 +847,15 @@
     }
 
 
-    public Attributes lookup( ServiceContext lookupContext ) throws NamingException
+    public Attributes lookup( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            return head.lookup( next, lookupContext );
+            return head.lookup( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -857,14 +869,15 @@
     }
 
 
-    public boolean hasEntry( ServiceContext entryContext ) throws NamingException
+    public boolean hasEntry( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            return head.hasEntry( next, entryContext );
+            return head.hasEntry( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -878,14 +891,15 @@
     }
 
 
-    public void rename( ServiceContext renameContext ) throws NamingException
+    public void rename( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            head.rename( next, renameContext );
+            head.rename( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -898,14 +912,15 @@
     }
 
 
-    public void move( ServiceContext moveContext ) throws NamingException
+    public void move( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            head.move( next, moveContext );
+            head.move( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -918,14 +933,15 @@
     }
 
 
-    public void moveAndRename( ServiceContext moveAndRenameContext ) throws NamingException
+    public void moveAndRename( OperationContext opContext ) throws NamingException
     {
         Entry entry = getStartingEntry();
         Interceptor head = entry.configuration.getInterceptor();
         NextInterceptor next = entry.nextInterceptor;
+        
         try
         {
-            head.moveAndRename( next, moveAndRenameContext );
+            head.moveAndRename( next, opContext );
         }
         catch ( NamingException ne )
         {
@@ -1001,14 +1017,14 @@
                 }
 
 
-                public boolean compare( ServiceContext compareContext ) throws NamingException
+                public boolean compare( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.compare( next.nextInterceptor, compareContext );
+                        return interceptor.compare( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1022,14 +1038,14 @@
                 }
 
 
-                public Attributes getRootDSE( ServiceContext getRootDSEContext ) throws NamingException
+                public Attributes getRootDSE( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.getRootDSE( next.nextInterceptor, getRootDSEContext );
+                        return interceptor.getRootDSE( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1043,14 +1059,14 @@
                 }
 
 
-                public LdapDN getMatchedName( ServiceContext getMatchedNameContext ) throws NamingException
+                public LdapDN getMatchedName( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.getMatchedName( next.nextInterceptor, getMatchedNameContext );
+                        return interceptor.getMatchedName( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1064,14 +1080,14 @@
                 }
 
 
-                public LdapDN getSuffix( ServiceContext getSuffixContext ) throws NamingException
+                public LdapDN getSuffix( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.getSuffix( next.nextInterceptor, getSuffixContext );
+                        return interceptor.getSuffix( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1085,14 +1101,14 @@
                 }
 
 
-                public Iterator listSuffixes( ServiceContext emptyContext ) throws NamingException
+                public Iterator listSuffixes( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.listSuffixes( next.nextInterceptor, emptyContext );
+                        return interceptor.listSuffixes( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1106,14 +1122,14 @@
                 }
 
 
-                public void delete( ServiceContext deleteContext ) throws NamingException
+                public void delete( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.delete( next.nextInterceptor, deleteContext );
+                        interceptor.delete( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1126,14 +1142,14 @@
                 }
 
 
-                public void add( ServiceContext addContext ) throws NamingException
+                public void add( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.add( next.nextInterceptor, addContext );
+                        interceptor.add( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1146,14 +1162,14 @@
                 }
 
 
-                public void modify( ServiceContext modifyContext ) throws NamingException
+                public void modify( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.modify( next.nextInterceptor, modifyContext );
+                        interceptor.modify( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1186,14 +1202,14 @@
                 }
 
 
-                public NamingEnumeration list( LdapDN base ) throws NamingException
+                public NamingEnumeration list( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.list( next.nextInterceptor, base );
+                        return interceptor.list( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1229,14 +1245,14 @@
                 }
 
 
-                public Attributes lookup( ServiceContext lookupContext ) throws NamingException
+                public Attributes lookup( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.lookup( next.nextInterceptor, lookupContext );
+                        return interceptor.lookup( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1250,14 +1266,14 @@
                 }
 
 
-                public boolean hasEntry( ServiceContext entryContext ) throws NamingException
+                public boolean hasEntry( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        return interceptor.hasEntry( next.nextInterceptor, entryContext );
+                        return interceptor.hasEntry( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1271,14 +1287,14 @@
                 }
 
 
-                public void rename( ServiceContext renameContext ) throws NamingException
+                public void rename( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.rename( next.nextInterceptor, renameContext );
+                        interceptor.rename( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1291,14 +1307,14 @@
                 }
 
 
-                public void move( ServiceContext moveContext ) throws NamingException
+                public void move( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.move( next.nextInterceptor, moveContext );
+                        interceptor.move( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1311,7 +1327,7 @@
                 }
 
 
-                public void moveAndRename( ServiceContext moveAndRenameContext )
+                public void moveAndRename( OperationContext opContext )
                     throws NamingException
                 {
                     Entry next = getNextEntry();
@@ -1319,7 +1335,7 @@
 
                     try
                     {
-                        interceptor.moveAndRename( next.nextInterceptor, moveAndRenameContext );
+                        interceptor.moveAndRename( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1332,14 +1348,14 @@
                 }
 
 
-                public void bind( ServiceContext bindContext ) throws NamingException
+                public void bind( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
     
                     try
                     {
-                        interceptor.bind( next.nextInterceptor, bindContext );
+                        interceptor.bind( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1352,14 +1368,14 @@
                 }
 
 
-                public void unbind( ServiceContext unbindContext ) throws NamingException
+                public void unbind( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.unbind( next.nextInterceptor, unbindContext );
+                        interceptor.unbind( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1372,14 +1388,14 @@
                 }
 
 
-                public void addContextPartition( ServiceContext addContextPartitionContext ) throws NamingException
+                public void addContextPartition( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.addContextPartition( next.nextInterceptor, addContextPartitionContext );
+                        interceptor.addContextPartition( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {
@@ -1393,14 +1409,14 @@
                 }
 
 
-                public void removeContextPartition( ServiceContext removeContextPartition ) throws NamingException
+                public void removeContextPartition( OperationContext opContext ) throws NamingException
                 {
                     Entry next = getNextEntry();
                     Interceptor interceptor = next.configuration.getInterceptor();
 
                     try
                     {
-                        interceptor.removeContextPartition( next.nextInterceptor, removeContextPartition );
+                        interceptor.removeContextPartition( next.nextInterceptor, opContext );
                     }
                     catch ( NamingException ne )
                     {

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java Sun Apr 15 12:08:12 2007
@@ -28,7 +28,7 @@
 import javax.naming.directory.Attributes;
 import javax.naming.directory.SearchControls;
 
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.partition.PartitionNexus;
 import org.apache.directory.shared.ldap.filter.ExprNode;
 import org.apache.directory.shared.ldap.message.ModificationItemImpl;
@@ -45,121 +45,121 @@
 public interface NextInterceptor
 {
     /**
-     * Calls the next interceptor's {@link Interceptor#compare( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#compare( NextInterceptor, OperationContext )}.
      */
-    boolean compare( ServiceContext compareContext ) throws NamingException;
+    boolean compare( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#getRootDSE( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#getRootDSE( NextInterceptor, OperationContext )}.
      */
-    Attributes getRootDSE( ServiceContext getRootDSEContext ) throws NamingException;
+    Attributes getRootDSE( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#getMatchedName( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#getMatchedName( NextInterceptor, OperationContext )}.
      */
-    LdapDN getMatchedName( ServiceContext getMatchedNameContext ) throws NamingException;
+    LdapDN getMatchedName( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#getSuffix( NextInterceptor, ServiceContext getSuffixContext )}.
+     * Calls the next interceptor's {@link Interceptor#getSuffix( NextInterceptor, OperationContext )}.
      */
-    LdapDN getSuffix( ServiceContext getSuffixContext ) throws NamingException;
+    LdapDN getSuffix( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#listSuffixes( NextInterceptor), ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#listSuffixes( NextInterceptor, OperationContext )}.
      */
-    Iterator listSuffixes( ServiceContext emptyContext ) throws NamingException;
+    Iterator listSuffixes( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link PartitionNexus#addContextPartition( ServiceContext )}.
+     * Calls the next interceptor's {@link PartitionNexus#addContextPartition( nextInterceptor, OperationContext )}.
      */
-    void addContextPartition( ServiceContext addContextPartitionContext ) throws NamingException;
+    void addContextPartition( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link PartitionNexus#removeContextPartition( ServiceContext )}.
+     * Calls the next interceptor's {@link PartitionNexus#removeContextPartition( NextInterceptor, OperationContext )}.
      */
-    void removeContextPartition( ServiceContext removeContextPartition ) throws NamingException;
+    void removeContextPartition( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#delete(NextInterceptor, org.apache.directory.shared.ldap.name.LdapDN)}.
+     * Calls the next interceptor's {@link Interceptor#delete(NextInterceptor, OperationContext )}.
      */
-    void delete( ServiceContext deleteContext ) throws NamingException;
+    void delete( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#add( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#add( NextInterceptor, OperationContext )}.
      */
-    void add( ServiceContext addContext ) throws NamingException;
+    void add( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#modify( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#modify( NextInterceptor, OperationContext )}.
      */
-    void modify( ServiceContext modifyContext ) throws NamingException;
+    void modify( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#modify(NextInterceptor,org.apache.directory.shared.ldap.name.LdapDN,javax.naming.directory.ModificationItem[])}.
+     * Calls the next interceptor's {@link Interceptor#modify( NextInterceptor,org.apache.directory.shared.ldap.name.LdapDN,javax.naming.directory.ModificationItem[])}.
      */
     void modify( LdapDN name, ModificationItemImpl[] items ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#list(NextInterceptor,org.apache.directory.shared.ldap.name.LdapDN)}.
+     * Calls the next interceptor's {@link Interceptor#list( NextInterceptor, OperationContext )}.
      */
-    NamingEnumeration list( LdapDN baseName ) throws NamingException;
+    NamingEnumeration list( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#search(NextInterceptor,org.apache.directory.shared.ldap.name.LdapDN,java.util.Map,org.apache.directory.shared.ldap.filter.ExprNode,javax.naming.directory.SearchControls)}.
+     * Calls the next interceptor's {@link Interceptor#search( NextInterceptor,org.apache.directory.shared.ldap.name.LdapDN,java.util.Map,org.apache.directory.shared.ldap.filter.ExprNode,javax.naming.directory.SearchControls)}.
      */
     NamingEnumeration search( LdapDN baseName, Map environment, ExprNode filter, SearchControls searchControls )
         throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#lookup( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#lookup( NextInterceptor, OperationContext )}.
      */
-    Attributes lookup( ServiceContext lookupContext ) throws NamingException;
+    Attributes lookup( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#hasEntry( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#hasEntry( NextInterceptor, OperationContext )}.
      */
-    boolean hasEntry( ServiceContext entryContext ) throws NamingException;
+    boolean hasEntry( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#rename( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#rename( NextInterceptor, OperationContext )}.
      */
-    void rename( ServiceContext renameContext ) throws NamingException;
+    void rename( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#move( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#move( NextInterceptor, OperationContext )}.
      */
-    void move( ServiceContext moveContext ) throws NamingException;
+    void move( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#moveAndRename( NextInterceptor, ServiceContext )}.
+     * Calls the next interceptor's {@link Interceptor#moveAndRename( NextInterceptor, OperationContext )}.
      */
-    void moveAndRename( ServiceContext moveAndRenameContext ) throws NamingException;
+    void moveAndRename( OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Calls the next interceptor's {@link Interceptor#bind( NextInterceptor, ServiceContext )}
+     * Calls the next interceptor's {@link Interceptor#bind( NextInterceptor, OperationContext )}
      */
-    void bind( ServiceContext bindContext ) throws NamingException;
+    void bind( OperationContext opContext ) throws NamingException;
 
     /**
-     * Calls the next interceptor's {@link Interceptor#unbind( NextInterceptor, ServiceContext ))}
+     * Calls the next interceptor's {@link Interceptor#unbind( NextInterceptor, OperationContext )}
      */
-    void unbind( ServiceContext unbindContext ) throws NamingException;
+    void unbind( OperationContext opContext ) throws NamingException;
 }

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,27 +28,27 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class AbstractServiceContext implements ServiceContext
+public class AbstractOperationContext implements OperationContext
 {
     /** The DN associated with the context */
     private LdapDN dn;
     
     /**
      * 
-     * Creates a new instance of AbstractServiceContext.
+     * Creates a new instance of AbstractOperationContext.
      *
      */
-    public AbstractServiceContext()
+    public AbstractOperationContext()
     {
     }
 
     /**
      * 
-     * Creates a new instance of AbstractServiceContext.
+     * Creates a new instance of AbstractOperationContext.
      *
      * @param dn The associated DN
      */
-    public AbstractServiceContext( LdapDN dn )
+    public AbstractOperationContext( LdapDN dn )
     {
         this.dn = dn;
     }

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddContextPartitionOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddContextPartitionServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddContextPartitionOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddContextPartitionServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddContextPartitionOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddContextPartitionServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddContextPartitionOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,24 +28,24 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class AddContextPartitionServiceContext  extends EmptyServiceContext
+public class AddContextPartitionOperationContext  extends EmptyOperationContext
 {
     /** The context partition configuration */
     private PartitionConfiguration cfg;
     
     /**
-     * Creates a new instance of AddContextPartitionServiceContext.
+     * Creates a new instance of AddContextPartitionOperationContext.
      */
-    public AddContextPartitionServiceContext()
+    public AddContextPartitionOperationContext()
     {
     }
     
     /**
-     * Creates a new instance of AddContextPartitionServiceContext.
+     * Creates a new instance of AddContextPartitionOperationContext.
      *
      * @param entryDn The partition configuration to add
      */
-    public AddContextPartitionServiceContext( PartitionConfiguration cfg )
+    public AddContextPartitionOperationContext( PartitionConfiguration cfg )
     {
         super();
         this.cfg = cfg;
@@ -56,7 +56,7 @@
      */
     public String toString()
     {
-        return "AddContextPartitionServiceContext for partition context '" + cfg.getName() + "'";
+        return "AddContextPartitionOperationContext for partition context '" + cfg.getName() + "'";
     }
 
     /**

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/AddOperationContext.java Sun Apr 15 12:08:12 2007
@@ -31,37 +31,37 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class AddServiceContext extends AbstractServiceContext
+public class AddOperationContext extends AbstractOperationContext
 {
     /** The added Attribute  */
     private Attributes entry;
     
     /**
      * 
-     * Creates a new instance of AddServiceContext.
+     * Creates a new instance of AddOperationContext.
      *
      */
-    public AddServiceContext()
+    public AddOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of AddServiceContext.
+     * Creates a new instance of AddOperationContext.
      *
      */
-    public AddServiceContext( LdapDN dn )
+    public AddOperationContext( LdapDN dn )
     {
         super( dn );
     }
 
     /**
      * 
-     * Creates a new instance of ModifyServiceContext.
+     * Creates a new instance of ModifyOperationContext.
      *
      */
-    public AddServiceContext( LdapDN dn, Attributes entry )
+    public AddOperationContext( LdapDN dn, Attributes entry )
     {
     	super( dn );
         this.entry = entry;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/BindOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/BindServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/BindOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/BindServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/BindOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/BindServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/BindOperationContext.java Sun Apr 15 12:08:12 2007
@@ -30,7 +30,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class BindServiceContext extends AbstractServiceContext
+public class BindOperationContext extends AbstractOperationContext
 {
     /** The list of supported mechanisms */
     private List<String> mechanisms;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/CompareOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/CompareServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/CompareOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/CompareServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/CompareOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/CompareServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/CompareOperationContext.java Sun Apr 15 12:08:12 2007
@@ -29,7 +29,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class CompareServiceContext  extends AbstractServiceContext
+public class CompareOperationContext  extends AbstractOperationContext
 {
     /** The entry OID */
     private String oid;
@@ -39,30 +39,30 @@
     
     /**
      * 
-     * Creates a new instance of CompareServiceContext.
+     * Creates a new instance of CompareOperationContext.
      *
      */
-    public CompareServiceContext()
+    public CompareOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of CompareServiceContext.
+     * Creates a new instance of CompareOperationContext.
      *
      */
-    public CompareServiceContext( LdapDN dn )
+    public CompareOperationContext( LdapDN dn )
     {
         super( dn );
     }
 
     /**
      * 
-     * Creates a new instance of LookupServiceContext.
+     * Creates a new instance of LookupOperationContext.
      *
      */
-    public CompareServiceContext( String oid )
+    public CompareOperationContext( String oid )
     {
     	super();
         this.oid = oid;
@@ -70,10 +70,10 @@
 
     /**
      * 
-     * Creates a new instance of LookupServiceContext.
+     * Creates a new instance of LookupOperationContext.
      *
      */
-    public CompareServiceContext( LdapDN dn, String oid )
+    public CompareOperationContext( LdapDN dn, String oid )
     {
     	super( dn );
         this.oid = oid;
@@ -81,10 +81,10 @@
 
     /**
      * 
-     * Creates a new instance of LookupServiceContext.
+     * Creates a new instance of LookupOperationContext.
      *
      */
-    public CompareServiceContext( LdapDN dn, String oid, Object value )
+    public CompareOperationContext( LdapDN dn, String oid, Object value )
     {
     	super( dn );
         this.oid = oid;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/DeleteOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/DeleteServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/DeleteOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/DeleteServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/DeleteOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/DeleteServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/DeleteOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,22 +28,22 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class DeleteServiceContext  extends AbstractServiceContext
+public class DeleteOperationContext  extends AbstractOperationContext
 {
     /**
-     * Creates a new instance of DeleteServiceContext.
+     * Creates a new instance of DeleteOperationContext.
      */
-    public DeleteServiceContext()
+    public DeleteOperationContext()
     {
         super();
     }
     
     /**
-     * Creates a new instance of DeleteServiceContext.
+     * Creates a new instance of DeleteOperationContext.
      *
      * @param deleteDn The entry DN to delete
      */
-    public DeleteServiceContext( LdapDN deleteDn )
+    public DeleteOperationContext( LdapDN deleteDn )
     {
         super( deleteDn );
     }

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EmptyOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EmptyServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EmptyOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EmptyServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EmptyOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EmptyServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EmptyOperationContext.java Sun Apr 15 12:08:12 2007
@@ -23,17 +23,17 @@
 
 /**
  * An EmptySuffix context used for Interceptors. It contains no data, and mask
- * the DN in AbstractServiceContext
+ * the DN in AbstractOperationContext
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class EmptyServiceContext implements ServiceContext
+public class EmptyOperationContext implements OperationContext
 {
     /**
-     * Creates a new instance of EmptyServiceContext.
+     * Creates a new instance of EmptyOperationContext.
      */
-    public EmptyServiceContext()
+    public EmptyOperationContext()
     {
         super();
     }
@@ -61,6 +61,6 @@
      */
     public String toString()
     {
-        return "EmptyServiceContext";
+        return "EmptyOperationContext";
     }
 }

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EntryOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EntryServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EntryOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EntryServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EntryOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EntryServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/EntryOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,21 +28,21 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class EntryServiceContext  extends AbstractServiceContext
+public class EntryOperationContext  extends AbstractOperationContext
 {
     /**
-     * Creates a new instance of EntryServiceContext.
+     * Creates a new instance of EntryOperationContext.
      */
-    public EntryServiceContext()
+    public EntryOperationContext()
     {
     }
     
     /**
-     * Creates a new instance of EntryServiceContext.
+     * Creates a new instance of EntryOperationContext.
      *
      * @param entryDn The Entry DN to unbind
      */
-    public EntryServiceContext( LdapDN entryDn )
+    public EntryOperationContext( LdapDN entryDn )
     {
         super( entryDn );
     }

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetMatchedNameOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetMatchedNameServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetMatchedNameOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetMatchedNameServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetMatchedNameOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java Sun Apr 15 12:08:12 2007
@@ -29,9 +29,8 @@
 import javax.naming.directory.SearchControls;
 
 import org.apache.directory.server.core.DirectoryServiceConfiguration;
-import org.apache.directory.server.core.configuration.PartitionConfiguration;
 import org.apache.directory.server.core.configuration.InterceptorConfiguration;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.partition.Partition;
 import org.apache.directory.server.core.partition.PartitionNexus;
 import org.apache.directory.shared.ldap.filter.ExprNode;
@@ -119,63 +118,63 @@
 
 
     /**
      * Filters {@link PartitionNexus#getRootDSE( ServiceContext )} call.
      */
-    Attributes getRootDSE( NextInterceptor next, ServiceContext getRootDSEContext ) throws NamingException;
+    Attributes getRootDSE( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link PartitionNexus#getMatchedName( ServiceContext )} call.
      */
-    LdapDN getMatchedName( NextInterceptor next, ServiceContext getMatchedNameContext ) throws NamingException;
+    LdapDN getMatchedName( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link PartitionNexus#getSuffix( ServiceContext )} call.
      */
-    LdapDN getSuffix ( NextInterceptor next, ServiceContext getSuffixContext ) throws NamingException;
+    LdapDN getSuffix ( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link PartitionNexus#listSuffixes( ServiceContext )} call.
      */
-    Iterator listSuffixes( NextInterceptor next, ServiceContext emptyContext ) throws NamingException;
+    Iterator listSuffixes( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link PartitionNexus#addContextPartition( ServiceContext )} call.
      */
-    void addContextPartition( NextInterceptor next, ServiceContext addContextPartitionContext ) throws NamingException;
+    void addContextPartition( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link PartitionNexus#removeContextPartition( ServiceContext )} call.
      */
-    void removeContextPartition( NextInterceptor next, ServiceContext removeContextPartition ) throws NamingException;
+    void removeContextPartition( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link PartitionNexus#compare( ServiceContext )} call.
      */
-    boolean compare( NextInterceptor next, ServiceContext  compareContext) throws NamingException;
+    boolean compare( NextInterceptor next, OperationContext  opContext) throws NamingException;
 
 
     /**
      * Filters {@link Partition#delete( ServiceContext )} call.
      */
-    void delete( NextInterceptor next, ServiceContext deleteContext ) throws NamingException;
+    void delete( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link Partition#add( ServiceContext )} call.
      */
-    void add( NextInterceptor next, ServiceContext addContext ) throws NamingException;
+    void add( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link Partition#modify( ServiceContext )} call.
      */
-    void modify( NextInterceptor next, ServiceContext modifyContext ) throws NamingException;
+    void modify( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
@@ -185,9 +184,9 @@
 
 
     /**
-     * Filters {@link Partition#list(org.apache.directory.shared.ldap.name.LdapDN)} call.
+     * Filters {@link Partition#list(OperationContext)} call.
      */
-    NamingEnumeration list( NextInterceptor next, LdapDN baseName ) throws NamingException;
+    NamingEnumeration list( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
@@ -198,43 +197,43 @@
 
 
     /**
      * Filters {@link Partition#lookup( ServiceContext )} call.
      */
-    Attributes lookup( NextInterceptor next, ServiceContext lookupContext ) throws NamingException;
+    Attributes lookup( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link Partition#hasEntry( ServiceContext )} call.
      */
-    boolean hasEntry( NextInterceptor next, ServiceContext entryContext ) throws NamingException;
+    boolean hasEntry( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link Partition#rename( ServiceContext )} call.
      */
-    void rename( NextInterceptor next, ServiceContext renameContext ) throws NamingException;
+    void rename( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
      * Filters {@link Partition#move( ServiceContext )} call.
      */
-    void move( NextInterceptor next, ServiceContext moveContext ) throws NamingException;
+    void move( NextInterceptor next, OperationContext opContext ) throws NamingException;
 
 
     /**
-     * Filters {@link Partition#moveAndRename( ServiceContext) } call.
+     * Filters {@link Partition#moveAndRename( OperationContext) } call.
      */
-    void moveAndRename( NextInterceptor next, ServiceContext moveAndRenameContext )
+    void moveAndRename( NextInterceptor next, OperationContext opContext )
         throws NamingException;
 
     /**
      * Filters {@link Partition#bind( ServiceContext )} call.
      */
-    void bind( NextInterceptor next, ServiceContext bindContext )
+    void bind( NextInterceptor next, OperationContext opContext )
         throws NamingException;
 
     /**
      * Filters {@link Partition#unbind( ServiceContext )} call.
      */
-    void unbind( NextInterceptor next, ServiceContext unbindContext ) throws NamingException;
+    void unbind( NextInterceptor next, OperationContext opContext ) throws NamingException;
 }
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link PartitionNexus#getRootDSE( ServiceContext )} call.
+     * Filters {@link PartitionNexus#getRootDSE( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link PartitionNexus#getMatchedName( ServiceContext )} call.
+     * Filters {@link PartitionNexus#getMatchedName( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link PartitionNexus#getSuffix( ServiceContext )} call.
+     * Filters {@link PartitionNexus#getSuffix( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link PartitionNexus#listSuffixes( ServiceContext )} call.
+     * Filters {@link PartitionNexus#listSuffixes( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link PartitionNexus#addContextPartition( ServiceContext )} call.
+     * Filters {@link PartitionNexus#addContextPartition( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link PartitionNexus#removeContextPartition( ServiceContext )} call.
+     * Filters {@link PartitionNexus#removeContextPartition( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link PartitionNexus#compare( ServiceContext )} call.
+     * Filters {@link PartitionNexus#compare( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link Partition#delete( ServiceContext )} call.
+     * Filters {@link Partition#delete( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link Partition#add( ServiceContext )} call.
+     * Filters {@link Partition#add( OperationContext )} call.
      */
@@ -119,63 +118,63 @@
 
     /**
-     * Filters {@link Partition#modify( ServiceContext )} call.
+     * Filters {@link Partition#modify( OperationContext )} call.
      */
@@ -198,43 +197,43 @@
 
     /**
-     * Filters {@link Partition#lookup( ServiceContext )} call.
+     * Filters {@link Partition#lookup( OperationContext )} call.
      */
@@ -198,43 +197,43 @@
 
     /**
-     * Filters {@link Partition#hasEntry( ServiceContext )} call.
+     * Filters {@link Partition#hasEntry( OperationContext )} call.
      */
@@ -198,43 +197,43 @@
 
     /**
-     * Filters {@link Partition#rename( ServiceContext )} call.
+     * Filters {@link Partition#rename( OperationContext )} call.
      */
@@ -198,43 +197,43 @@
 
     /**
-     * Filters {@link Partition#move( ServiceContext )} call.
+     * Filters {@link Partition#move( OperationContext )} call.
      */
@@ -198,43 +197,43 @@
 
     /**
-     * Filters {@link Partition#bind( ServiceContext )} call.
+     * Filters {@link Partition#bind( OperationContext )} call.
      */
@@ -198,43 +197,43 @@
 
     /**
-     * Filters {@link Partition#unbind( ServiceContext )} call.
+     * Filters {@link Partition#unbind( OperationContext )} call.
      */

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetMatchedNameServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetMatchedNameOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,22 +28,22 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class GetMatchedNameServiceContext  extends AbstractServiceContext
+public class GetMatchedNameOperationContext  extends AbstractOperationContext
 {
     /**
      * Creates a new instance of GetMatchedNameServiceContext.
      */
-    public GetMatchedNameServiceContext()
+    public GetMatchedNameOperationContext()
     {
         super();
     }
     
     /**
      * Creates a new instance of GetMatchedNameServiceContext.
      *
      * @param dn The DN to match
      */
-    public GetMatchedNameServiceContext( LdapDN dn )
+    public GetMatchedNameOperationContext( LdapDN dn )
     {
         super( dn );
     }
@@ -28,22 +28,22 @@
 {
     /**
-     * Creates a new instance of GetMatchedNameServiceContext.
+     * Creates a new instance of GetMatchedNameOperationContext.
      */
@@ -28,22 +28,22 @@
     
     /**
-     * Creates a new instance of GetMatchedNameServiceContext.
+     * Creates a new instance of GetMatchedNameOperationContext.
      *
      * @param dn The DN to match